<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "xen";

    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'xen/opt_name', $opt_name );

    /*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
     *
     */

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
		'class'                => 'admin-color-pimax',
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_html__( 'XEN Options', 'xen' ),
        'page_title'           => esc_html__( 'XEN Options', 'xen' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => 'AIzaSyCN8bSGZHdbSOXu0HbhXf8j0SnswTmbCNw',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => true,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => false,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => 90,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the xen. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'xen'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'xen'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    
    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf( esc_html__( '', 'xen' ), $v );
    } else {
        $args['intro_text'] = esc_html__( '', 'xen' );
    }

    // Add content after the form.
    $args['footer_text'] = esc_html__( '', 'xen' );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Support', 'xen' ),
            'content' => esc_html__( 'Send us a mail by using our item support form.', 'xen' )
        ),
        
    );
    Redux::set_help_tab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_html__( 'Send us a mail by using our item support form.', 'xen' );
    Redux::set_help_sidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // ACTUAL DECLARATION OF SECTIONS
                Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'General Settings', 'xen' ),
                    'desc'   => esc_html__( '', 'xen' ),
                    'icon'   => 'el-icon-home-alt',
                    // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                    'fields' => array(
					
					array(
			                'id' => 'notice_header_logo',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Logo Options', 'xen'),
			                'desc' => esc_html__('Logo options of your site header.', 'xen')
			            ),
					
					 array(
							'id' => 'textlogo',
							'type' => 'button_set',
							'title' => esc_html__('Select Logo Format', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Text Logo', 'xen'),
									'st2' => esc_html__('Image Logo', 'xen'),
							),
							'default'  => 'st1'
					),
					 
					array(
							'id' => 'logopic',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_html__('Upload Dark Logo', 'xen'),
							'subtitle' => esc_html__('Working on menu style Transparent Dark & White Background options.', 'xen'),
							'required' => array('textlogo', '=' , 'st2')
					),
					
					array(
							'id' => 'logopiclight',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_html__('Upload Light Logo', 'xen'),
							'subtitle' => esc_html__('Working on menu style Transparent Light option.', 'xen'),
							'required' => array('textlogo', '=' , 'st2')
					),
					
					$fields = array(
						'id'       => 'opt_logo_dimensions',
						'type'     => 'dimensions',
						'units'    => array('em','px','%'),
						'output' => array('.logo-img-box img'),
						'title'    => __('Logo Size', 'xen'),
						'subtitle' => __('.', 'xen'),
						'desc'     => __('Optional', 'xen'),
						'default'  => array(
							'Width'   => '100', 
							'Height'  => '26'
						),
						'required' => array('textlogo', '=' , 'st2')
					),
				
				array(
							'id' => 'logotext',
							'type' => 'text',
							'title' => esc_html__('Logo Text ', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'required' => array('textlogo', '=' , 'st1')
					
				),
				
				array(
							'id' => 'nav_logo_opt',
							'type' => 'button_set',
							'title' => esc_html__('Navigation Logo', 'xen'),
							'subtitle' => esc_html__('Enable/ Disable logo for menu section.', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'xen'),
									'st2' => esc_html__('Enable', 'xen'),
									
							),
							'default'  => 'st1',
							'required' => array('textlogo', '=' , 'st2')
					),
				
				array(
							'id' => 'xen_preloader',
							'type' => 'button_set',
							'title' => esc_html__('Preloader', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'xen'),
									'st2' => esc_html__('Enable', 'xen'),
									
							),
							'default'  => 'st1'
					),
					
					array(
							'id' => 'pagelogopic',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_html__('Upload  Preloader Logo', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'required' => array('xen_preloader', '=' , 'st2')
							
					),
					
					$fields = array(
						'id'       => 'opt_pre_loader__logo_dimensions',
						'type'     => 'dimensions',
						'units'    => array('em','px','%'),
						'output' => array('.logo-loading'),
						'title'    => __('Preloader Logo Size', 'xen'),
						'subtitle' => __('.', 'xen'),
						'desc'     => __('Optional', 'xen'),
						'default'  => array(
							'Width'   => '70', 
							'Height'  => '70'
						),
						'required' => array('xen_preloader', '=' , 'st2')
					),
					
					$fields = array(
						'id'       => 'opt_pre_loader_circle_logo_dimensions',
						'type'     => 'dimensions',
						'units'    => array('em','px','%'),
						'output' => array('.loading'),
						'title'    => __('Preloader Circle Size', 'xen'),
						'subtitle' => __('.', 'xen'),
						'desc'     => __('Optional', 'xen'),
						'default'  => array(
							'Width'   => '100', 
							'Height'  => '100'
						),
						'required' => array('xen_preloader', '=' , 'st2')
					),
					
					array(
							'id' => 'enablecursor',
							'type' => 'button_set',
							'title' => esc_attr__('Custom Cursor', 'xen'),
							'subtitle' => esc_attr__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'xen'),
									'st2' => esc_html__('Enable', 'xen'),
									
							),
							'default'  => 'st1'
					),
					
					
				  )
               ) );
			   
			  
			   
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-bullhorn',
                    'title'  => esc_html__( '404 Page Options', 'xen' ),
                    'fields' => array(
					
					array(
							'id' => '404back',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_html__('Upload  404 Page Background Image', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							
					),
					
					array(
			                'id' => 'notice_404page_translation',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('404 Page Translate Options', 'xen'),
			                'desc' => esc_html__('404 Page Text Translate Options', 'xen'),
							
			            ),
						
					array(
							'id' => '404_page_title_1',
							'type' => 'text',
							'compiler' => 'true',
							'title' => esc_html__('Text 1', 'xen'),
							'subtitle' => esc_html__('Translate Options. E.X:  Error ', 'xen'),
							
					),
					
					array(
							'id' => '404_page_title_2',
							'type' => 'text',
							'compiler' => 'true',
							'title' => esc_html__('Text 2', 'xen'),
							'subtitle' => esc_html__('Translate Options. E.X:  Sorry Page Not Found. ', 'xen'),
							
					),
					
					array(
							'id' => '404_page_title_3',
							'type' => 'text',
							'compiler' => 'true',
							'title' => esc_html__('Text 3', 'xen'),
							'subtitle' => esc_html__('Translate Options. E.X:  Search', 'xen'),
					),
					
					array(
							'id' => '404_page_title_4',
							'type' => 'text',
							'compiler' => 'true',
							'title' => esc_html__('Text 4', 'xen'),
							'subtitle' => esc_html__('Translate Options. E.X:  Search Agian', 'xen'),
					),
					
					 )
                ) );
				
			
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-bullhorn',
                    'title'  => esc_html__( 'Blog & Portfolio Options', 'xen' ),
                    'fields' => array(
					array(
			                'id' => 'notice_index_main_page_opt',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Blog Style', 'xen'),
			                'desc' => esc_html__('Select blog page style of your site. Page Template also available.', 'xen')
			        ),
					array(
							'id' => 'blogtyle',
							'type' => 'button_set',
							'title' => esc_html__('Select Blog Layout', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Right Sidebar', 'xen'),
									'st2' => esc_html__('Left Sidebar', 'xen'),
									'st3' => esc_html__('Full Width', 'xen'),
							),
							'default'  => 'st1'
					),
					
					array(
							'id' => 'blog_sidebar_back_opt',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_html__('Upload Index Header Image', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
					),
					
					array(
							'id' => 'blog_animated_back_color_opt',
							'type' => 'button_set',
							'title' => esc_html__('Background Color', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Dark 1', 'xen'),
									'st2' => esc_html__('Dark 2', 'xen'),
							),
							'default'  => 'st1'
					),
					
					array(
							'id' => 'blog_midnight_color_opt',
							'type' => 'button_set',
							'title' => esc_html__('Logo & Menu Button Style', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Light', 'xen'),
									'st2' => esc_html__('Dark', 'xen'),
							),
							'default'  => 'st1'
					),
					
					array(
			                'id' => 'notice_index_details_main_page_opt',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Blog Details Page Style', 'xen'),
			                'desc' => esc_html__('Select blog details page style of your site. You can select details style from post also.', 'xen')
			        ),
					
					array(
							'id' => 'blogdetailstyle',
							'type' => 'button_set',
							'title' => esc_html__('Select Blog Details Layout', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Right Sidebar', 'xen'),
									'st2' => esc_html__('Left Sidebar', 'xen'),
									'st3' => esc_html__('Full Width', 'xen'),
									
							),
							'default'  => 'st1'
					),
					
					array(
							'id' => 'blogdetailstyle_featured',
							'type' => 'button_set',
							'title' => esc_html__('Details Page Featured Image', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Enable', 'xen'),
									'st2' => esc_html__('Disable', 'xen'),
							),
							'default'  => 'st1'
					),
					
					array(
			                'id' => 'notice_header_page_title_translation',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Index Page Title Options', 'xen'),
			                'desc' => esc_html__('Working only sidebar style.', 'xen'),
							'required' => array('headersearch_opt', '=' , 'st2')
			        ),
					
					array(
							'id' => 'blogtitle',
							'type' => 'text',
							'title' => esc_html__('Index Title ', 'xen'),
							'subtitle' => esc_html__('Write header title for index page here. Ex: My Blog', 'xen'),
					),
					
					array(
							'id' => 'blog_sub_title',
							'type' => 'text',
							'title' => esc_html__('Index Sub Title. ', 'xen'),
							'subtitle' => esc_html__('Write header sub title for index page here. Ex: Articles & News', 'xen'),
					),
					
					array(
							'id' => 'arch-page-title',
							'type' => 'text',
							'title' => esc_html__('Archive Page Title', 'xen'),
							'subtitle' => esc_html__('Write header title for blog archive page here. Ex: Archive', 'xen'),
							'default' => '',
					),	
					array(
							'id' => 'cat-page-title',
							'type' => 'text',
							'title' => esc_html__('Category Page Title', 'xen'),
							'subtitle' => esc_html__('Write header title for blog category page here. Ex: Category', 'xen'),
							'default' => '',
					),	
	
					array(
							'id' => 'tag-page-title',
							'type' => 'text',
							'title' => esc_html__('Tag Page Title', 'xen'),
							'subtitle' => esc_html__('Write header title for blog tag page here. Ex: Tag', 'xen'),
							'default' => '',
					),	
					
					array(
							'id' => 'search-page-title',
							'type' => 'text',
							'title' => esc_html__('Search Page Title', 'xen'),
							'subtitle' => esc_html__('Write header title for blog tag page here. Ex: Search results for', 'xen'),
							'default' => '',
					),	
					
					array(
			                'id' => 'notice_share_index',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Post Details Share Option', 'xen'),
			                'desc' => esc_html__('Enable/ Disable post details page share option.', 'xen')
			        ),
					
					array(
							'id' => 'index_details_share',
							'type' => 'button_set',
							'title' => esc_html__('Share Option', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'xen'),
									'st2' => esc_html__('Enable', 'xen'),
							),
							'default'  => 'st1'
					),
					
					array(
			                'id' => 'notice_details_share_translation',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Translate Options', 'xen'),
			                'desc' => esc_html__('Share section text translate option.', 'xen'),
							'required' => array('index_details_share', '=' , 'st2')
			        ),
					
					array(
							'id' => 'share_sec_title',
							'type' => 'text',
							'compiler' => 'true',
							'title' => esc_html__('Text 1', 'xen'),
							'subtitle' => esc_html__('E.X: Share', 'xen'),
							'required' => array('index_details_share', '=' , 'st2')
					),
					
					array(
			                'id' => 'notice_related_index',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Post Details Related Post', 'xen'),
			                'desc' => esc_html__('Enable/ Disable post details page related post option.', 'xen')
			        ),
					
					array(
							'id' => 'index_details_related',
							'type' => 'button_set',
							'title' => esc_html__('Related Post Section', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'xen'),
									'st2' => esc_html__('Enable', 'xen'),
							),
							'default'  => 'st1'
					),
					
					array(
			                'id' => 'notice_details_related_translation',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Translate Options', 'xen'),
			                'desc' => esc_html__('Related post section text translate option.', 'xen'),
							'required' => array('index_details_related', '=' , 'st2')
			        ),
					
					array(
							'id' => 'related_sec_title',
							'type' => 'text',
							'compiler' => 'true',
							'title' => esc_html__('Text 1', 'xen'),
							'subtitle' => esc_html__('E.X: You might also like', 'xen'),
							'required' => array('index_details_related', '=' , 'st2')
					),
					
					
					array(
			                'id' => 'notice_user_details_index',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Post Details Admin Information.', 'xen'),
			                'desc' => esc_html__('Enable/ Disable post details admin information.', 'xen')
			        ),
					
					array(
							'id' => 'index_details_user_dt_opt',
							'type' => 'button_set',
							'title' => esc_html__('Admin Information', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'xen'),
									'st2' => esc_html__('Enable', 'xen'),
							),
							'default'  => 'st1'
					),
					
					array(
			                'id' => 'notice_port_details_opt',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Portfolio Option.', 'xen'),
			                'desc' => esc_html__('Portfolio Details Page Option.', 'xen')
			        ),
					
					array(
							'id' => 'port_post_pagination',
							'type' => 'button_set',
							'title' => esc_html__('Portfolio Pagination', 'xen'),
							'subtitle' => esc_html__('Portfolio Details Page Pagination', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Enable', 'xen'),
									'st2' => esc_html__('Disable', 'xen'),
							),
							'default'  => 'st1'
					),
					
                    )
                ) );
				
				if (class_exists('WooCommerce')) {
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-shopping-cart-sign',
                    'title'  => esc_attr__( 'Shop Options', 'xen' ),
                    'fields' => array(
					
					array(
							'id' => 'wr-shop-opt',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_attr__('Shop Page Header Options', 'xen'),
							'desc' => esc_attr__(' ', 'xen')
							
					  ),

					array(
							'id' => 'shopheaderimg',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_attr__('Upload Shop Page Header Image', 'xen'),
							'subtitle' => esc_attr__('', 'xen'),
							
					),
					
					array(
							'id' => 'shop_animated_back_color_opt',
							'type' => 'button_set',
							'title' => esc_html__('Background Color', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Dark 1', 'xen'),
									'st2' => esc_html__('Dark 2', 'xen'),
							),
							'default'  => 'st1'
					),
					
					array(
							'id' => 'shop_midnight_color_opt',
							'type' => 'button_set',
							'title' => esc_html__('Logo & Menu Button Style', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Light', 'xen'),
									'st2' => esc_html__('Dark', 'xen'),
							),
							'default'  => 'st1'
					),
					
					array(
							'id' => 'shop_animated_title_opt',
							'type' => 'button_set',
							'title' => esc_html__('Animated Title', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'xen'),
									'st2' => esc_html__('Enable', 'xen'),
							),
							'default'  => 'st1'
					),
					
					array(
							'id' => 'shop_animated_title_1',
							'type' => 'text',
							'title' => esc_html__('Animated Title 1 ', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'required' => array('shop_animated_title_opt', '=' , 'st2')
					),
					
					array(
							'id' => 'shop_animated_title_2',
							'type' => 'text',
							'title' => esc_html__('Animated Title 2 ', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'required' => array('shop_animated_title_opt', '=' , 'st2')
					),
					
					array(
							'id' => 'shop_animated_title_3',
							'type' => 'text',
							'title' => esc_html__('Animated Title 3 ', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'required' => array('shop_animated_title_opt', '=' , 'st2')
					),
					
					array(
							'id' => 'shopsubtitle',
							'type' => 'text',
							'title' => esc_attr__('Sub Title ', 'xen'),
							'subtitle' => esc_attr__('Shop page sub title', 'xen'),
					),
					
					array(
			                'id' => 'notice_share_shop',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Product Details Share Option', 'xen'),
			                'desc' => esc_html__('Enable/ Disable product details page share option.', 'xen')
			        ),
					
					array(
							'id' => 'shop_details_share',
							'type' => 'button_set',
							'title' => esc_html__('Share Option', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'xen'),
									'st2' => esc_html__('Enable', 'xen'),
							),
							'default'  => 'st1'
					),
					
					array(
			                'id' => 'notice_details_share_translation_shop',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Translate Option', 'xen'),
			                'desc' => esc_html__('Share section text translate option.', 'xen'),
							'required' => array('shop_details_share', '=' , 'st2')
			        ),
					
					array(
							'id' => 'share_sec_title_shop',
							'type' => 'text',
							'compiler' => 'true',
							'title' => esc_html__('Text 1', 'xen'),
							'subtitle' => esc_html__('E.X: Share', 'xen'),
							'required' => array('index_details_share', '=' , 'st2')
					),
					
					
                    )
                ) );
				}
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-cog',
                    'title'  => __( 'Translate Options', 'xen' ),
                    'fields' => array(
					
					array(
							'id' => 'wr-blog-opt2',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_html__('Translate Text', 'xen'),
							'desc' => esc_html__(' ', 'xen')
							
					  ),

					array(
							'id' => 'translet_opt_1',
							'type' => 'text',
							'title' => esc_html__('Scroll', 'xen'),
							'subtitle' => esc_html__('Index & Shop.', 'xen'),
					),
					
					array(
							'id' => 'translet_opt_6',
							'type' => 'text',
							'title' => esc_html__('Type & Hit Enter...', 'xen'),
							'subtitle' => esc_html__('Search Widget Placeholder.', 'xen'),
					),
					
					array(
							'id' => 'translet_opt_10',
							'type' => 'text',
							'title' => esc_html__('One thought on', 'xen'),
							'subtitle' => esc_html__('Post Comment Section.', 'xen'),
					),
					
					array(
							'id' => 'translet_opt_11',
							'type' => 'text',
							'title' => esc_html__('thought on', 'xen'),
							'subtitle' => esc_html__('Post Comment Section.', 'xen'),
					),
					
					array(
							'id' => 'translet_opt_12',
							'type' => 'text',
							'title' => esc_html__('thoughts on', 'xen'),
							'subtitle' => esc_html__('Post Comment Section.', 'xen'),
					),
					
					array(
							'id' => 'translet_opt_13',
							'type' => 'text',
							'title' => esc_html__('Comments are closed.', 'xen'),
							'subtitle' => esc_html__('Post Comment Section.', 'xen'),
					),
					
					array(
							'id' => 'translet_opt_14',
							'type' => 'text',
							'title' => esc_html__('Your Name', 'xen'),
							'subtitle' => esc_html__('Post Comment Section Form.', 'xen'),
					),
					
					array(
							'id' => 'translet_opt_15',
							'type' => 'text',
							'title' => esc_html__('Your Email', 'xen'),
							'subtitle' => esc_html__('Post Comment Section Form.', 'xen'),
					),
					
					array(
							'id' => 'translet_opt_16',
							'type' => 'text',
							'title' => esc_html__('Your Comment', 'xen'),
							'subtitle' => esc_html__('Post Comment Section Form.', 'xen'),
					),
					
					array(
							'id' => 'translet_opt_17',
							'type' => 'text',
							'title' => esc_html__('Submit Comment', 'xen'),
							'subtitle' => esc_html__('Post Comment Section Form.', 'xen'),
					),
					
					array(
							'id' => 'translet_opt_25',
							'type' => 'text',
							'title' => esc_html__('Leave a Reply', 'xen'),
							'subtitle' => esc_html__('Post Comment Section Form.', 'xen'),
					),
					
					array(
							'id' => 'translet_opt_18',
							'type' => 'text',
							'title' => esc_html__('Previous Project', 'xen'),
							'subtitle' => esc_html__('Portfolio Pagination.', 'xen'),
					),
					
										
					array(
							'id' => 'translet_opt_20',
							'type' => 'text',
							'title' => esc_html__('Next Project', 'xen'),
							'subtitle' => esc_html__('Portfolio Pagination.', 'xen'),
					),
					
					
					
					array(
							'id' => 'translet_opt_23',
							'type' => 'text',
							'title' => esc_html__('Nothing Found!', 'xen'),
							'subtitle' => esc_html__('Post Search Page.', 'xen'),
					),
					
					array(
							'id' => 'translet_opt_24',
							'type' => 'text',
							'title' => esc_html__('Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'xen'),
							'subtitle' => esc_html__('Post Search Page.', 'xen'),
					),
					
					
                    )
                ) );
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-text-width',
                    'title'  => esc_attr__( 'Typography', 'xen' ),
                    'fields' => array(  


						array(
                            'id'          => 'typo_body',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Body', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('body'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the Body Text font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_p_1',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('p, blockquote & li tag font properties.', 'xen'),
			                'desc' => esc_html__('Specify the p, blockquote & li tag font properties.', 'xen')
			            ),
						
						array(
                            'id'          => 'typo_post_li',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Post & Page li', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('article.entry-content ul, article.entry-content ol,.xen-textblock ul, .xen-textblock ol, .wpb_text_column ul, .wpb_text_column ol'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the blockquote font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_blockquote',
                            'type'        => 'typography', 
                            'title'       => esc_html__('blockquote', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('blockquote, blockquote p, .p-style-medium blockquote, .p-style-medium blockquote p'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the blockquote font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_p_s_d',
                            'type'        => 'typography', 
                            'title'       => esc_html__('p', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('p'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the p font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_p_s',
                            'type'        => 'typography', 
                            'title'       => esc_html__('p(S)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.p-style-small, .p-style-small p, .p-style-small a'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the p(s) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_p_xs',
                            'type'        => 'typography', 
                            'title'       => esc_html__('p(XS)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.p-style-xsmall, .p-style-xsmall p, .p-style-xsmall a'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the p(XS) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_p_m',
                            'type'        => 'typography', 
                            'title'       => esc_html__('p(M)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.p-style-medium, .p-style-medium p, .p-style-medium a'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the p(M) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_p_l',
                            'type'        => 'typography', 
                            'title'       => esc_html__('p(L)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.p-style-large, .p-style-large p, .p-style-large a'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the p(L) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_p_bold',
                            'type'        => 'typography', 
                            'title'       => esc_html__('p(Bold)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.p-style-bold, .p-style-bold p , .p-style-bold a'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the p(Bold) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_p_bold_u',
                            'type'        => 'typography', 
                            'title'       => esc_html__('p(Bold Upercase)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.p-style-bold-up, .p-style-bold-up p, .p-style-bold-up a'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the p(Bold Upercase) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_p_u',
                            'type'        => 'typography', 
                            'title'       => esc_html__('p(Upercase)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.p-letter-style, .p-letter-style p, .p-letter-style a'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the p( Upercase) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_hd_slider_opt',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Slider Title.', 'xen'),
			                'desc' => esc_html__('Page Header Type Slider Title Options.', 'xen')
			            ),
						
						array(
                            'id'          => 'typo_hd_slider_1st_title',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Slide Style 1 Title', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.home-slider-content.dark-bg-1 .large-title-bold.class-slider-title'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_hd_slider_2nd_title',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Slide Style 2 Title', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.home-slider-content .large-title-bold.class-slider-title.text-color-4'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_hd_slider_2nd_sub_title',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Slide Style 2 Sub Title', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.home-slider-content .red-color'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_hd_slider_3rd__title',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Slide Style 3 Title', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.home-slider-content.red-bg h1.large-title-bold.class-slider-title, .home-slider-content.red-bg h1.large-title-bold.class-slider-title *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'color'       => false,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_t_global',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('All title tag font properties.', 'xen'),
			                'desc' => esc_html__('Specify the all title tag font properties.', 'xen')
			            ),
						
						
						
						array(
                            'id'          => 'typo_t_h1',
                            'type'        => 'typography', 
                            'title'       => esc_html__('h1', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h1:not(.class-slider-title), h1:not(.class-slider-title) *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h1 font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h2',
                            'type'        => 'typography', 
                            'title'       => esc_html__('h2', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h2, h2 *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h2 font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h3',
                            'type'        => 'typography', 
                            'title'       => esc_html__('h3', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h3, h3 *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h3 font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h4',
                            'type'        => 'typography', 
                            'title'       => esc_html__('h4', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h4, h4 *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h4 font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h5',
                            'type'        => 'typography', 
                            'title'       => esc_html__('h5', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h5, h5 *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h5 font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h6',
                            'type'        => 'typography', 
                            'title'       => esc_html__('h6', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h6, h6 *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h6 font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_d',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Title(Default)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.title-style, .title-style *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the Title(Default) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_m',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Title(M)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.medium-title, .medium-title *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the Title(M) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_l',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Title(L)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.large-title, .large-title *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the Title(L) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_l_b',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Title(L Title Bold)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.large-title-bold:not(.class-slider-title), .large-title-bold:not(.class-slider-title) *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the Title(L Title Bold) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_x_l',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Title(XL)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.xlarge-title, .xlarge-title *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the Title(XL) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_t_x_x_l',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Title(XXL)', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.xxlarge-title, .xxlarge-title *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the Title(XXL) font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_sec_sub_title',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Section Sub Title & Blog Element Meta Text', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.xsmall-title-oswald, .xsmall-title-oswald *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the section sub title & blog element meta text font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_port_cat1',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Portfolio Element Category Ttile & Testimonial Client Name', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.small-title-oswald, .small-title-oswald *'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the portfolio element category tile & testimonial client name font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_menu_typo',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Menu & Button font properties.', 'xen'),
			                'desc' => esc_html__('Specify the menu & button font properties.', 'xen')
			            ),
						
						array(
                            'id'          => 'typo_menu1',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Menu Item', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.nav-btn'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the menu item font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_button1',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Border Button', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.border-btn'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the button font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_button_slider',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Slider Red Border Button', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.home-slider-content .border-btn-red .border-btn'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify slider red border button font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_button_slider_white',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Slider White Border Button', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.home-slider-content .border-btn-white .border-btn'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify slider white border button font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_button_slider_arrow',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Slider Arrow Button', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.home-slider-content.red-bg .arrow-btn'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify slider arrow button font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_button2',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Arrow Button', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.arrow-btn'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the button font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_button3',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Price Table Button', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.price-btn'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the button font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_button4',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Scroll To Button', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.scroll-btn-flip'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the page scroll to button font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_flipbutton4',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Flip Button', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.flip-btn, .footer-social li .flip-btn'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the Flip button font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_widget_typo',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Widget font properties.', 'xen'),
			                'desc' => esc_html__('Specify the widget font properties.', 'xen')
			            ),
						array(
                            'id'          => 'typo_widget_1',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Footer Widget Title', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.footer-widget .footer-title'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the footer widget title font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						array(
                            'id'          => 'typo_widget_2',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Footer Widget List Item', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.footer-widget li a'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the footer widget list item font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
						array(
                            'id'          => 'typo_widget_3',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Blog & Shop Widget List Item', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.single-side-bar.widget_categories li a, .single-side-bar.widget_archive li a, .single-side-bar.widget_meta li a, .single-side-bar.widget_pages li a, .single-side-bar.widget_nav_menu li a, .single-side-bar.widget_product_categories li a, .single-side-bar.widget_recent_entries li a, .single-side-bar.widget_tag_cloud a, .single-side-bar.widget_product_tag_cloud a'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the blog & Shop widget list item font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
					array(
			                'id' => 'notice_pott_pagination',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Portfolio Pagination font properties.', 'xen'),
			                'desc' => esc_html__('Specify the portfolio Pagination font properties.', 'xen')
			            ),
						array(
                            'id'          => 'typopagi_port_1',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Portfolio Pagination', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.overlay-btn'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the footer portfolio pagination font properties.', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),
						
					array(
			                'id' => 'notice_contact_form',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Contact form font properties.', 'xen'),
			                'desc' => esc_html__('Specify the Contact form font properties.', 'xen')
			        ),
						array(
                            'id'          => 'typopagi_form_1',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Contact Form Placeholder', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('::placeholder'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),	
						
						array(
                            'id'          => 'typopagi_form_2',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Label', 'xen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('form label'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('', 'xen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
						),	
                        
                    )
                ) );	
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-brush',
                    'title'  => esc_html__( 'Styling', 'xen' ),
                    'fields' => array(
					
					array(
			                'id' => 'notice_global_color',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Global Theme COlor', 'xen'),
			                'desc' => esc_html__('Global Red Color Only.', 'xen')
			        ),
					
					array(
                            'id'       => 'opt-theme-style',
                            'type'     => 'color',
                            'title'    => esc_html__( 'Theme Color Option', 'xen' ),
                            'subtitle' => esc_html__( 'Global Red Color Only.', 'xen' ),
                            'desc'     => esc_html__( 'Change all global color.', 'xen' ),
                            //'regular'   => false, // Disable Regular Color
                            //'hover'     => false, // Disable Hover Color
                            //'active'    => false, // Disable Active Color
                            //'visited'   => true,  // Enable Visited Color
                            
                   ),
				   
				   array(
			                'id' => 'notice_menu_background',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Menu Background Color', 'xen'),
			                'desc' => esc_html__('Menu Section Background Color.', 'xen')
			        ),
					
					array(
                            'id'       => 'opt-menu-background',
                            'type'     => 'color',
                            'title'    => esc_html__( 'Menu Section Background', 'xen' ),
                            'subtitle' => esc_html__( '', 'xen' ),
                            'desc'     => esc_html__( '', 'xen' ),
                            //'regular'   => false, // Disable Regular Color
                            //'hover'     => false, // Disable Hover Color
                            //'active'    => false, // Disable Active Color
                            //'visited'   => true,  // Enable Visited Color
                            
                   ),
				   
				  
				   array(
			                'id' => 'notice_slider_background',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Slider Background Color', 'xen'),
			                'desc' => esc_html__('Page Header Type Slider Background Color.', 'xen')
			        ),
					
					array(
                            'id'       => 'opt-slider-st1',
                            'type'     => 'color',
                            'title'    => esc_html__( 'Slider Style 1', 'xen' ),
                            'subtitle' => esc_html__( '', 'xen' ),
                            'desc'     => esc_html__( '', 'xen' ),
                            //'regular'   => false, // Disable Regular Color
                            //'hover'     => false, // Disable Hover Color
                            //'active'    => false, // Disable Active Color
                            //'visited'   => true,  // Enable Visited Color
                            
                   ),
				   
				   array(
                            'id'       => 'opt-slider-st2',
                            'type'     => 'color',
                            'title'    => esc_html__( 'Slider Style 2', 'xen' ),
                            'subtitle' => esc_html__( '', 'xen' ),
                            'desc'     => esc_html__( '', 'xen' ),
                            //'regular'   => false, // Disable Regular Color
                            //'hover'     => false, // Disable Hover Color
                            //'active'    => false, // Disable Active Color
                            //'visited'   => true,  // Enable Visited Color
                            
                   ),
				   
				   array(
                            'id'       => 'opt-slider-st3',
                            'type'     => 'color',
                            'title'    => esc_html__( 'Slider Style 3', 'xen' ),
                            'subtitle' => esc_html__( '', 'xen' ),
                            'desc'     => esc_html__( '', 'xen' ),
                            //'regular'   => false, // Disable Regular Color
                            //'hover'     => false, // Disable Hover Color
                            //'active'    => false, // Disable Active Color
                            //'visited'   => true,  // Enable Visited Color
                            
                   ),
						
					

                    )
                ) );
				
				
				
				
				 Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-th-large',
                    'title'  => esc_html__( 'Footer Options', 'xen' ),
                    'fields' => array(
					
					
					
					array(
			                'id' => 'notice_footer_logo',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Footer Logo Options', 'xen'),
			                'desc' => esc_html__('Enable/ Disable footer logo for your site footer.', 'xen')
			            ),
					
					array(
							'id' => 'en_footer_logo_opt',
							'type' => 'button_set',
							'title' => esc_html__('Footer Logo', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'xen'),
									'st2' => esc_html__('Enable', 'xen'),
							),
							'default'  => 'st1'
					),
					
					array(
							'id' => 'logopicfooter',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_html__('Upload  Footer Logo', 'xen'),
							'subtitle' => esc_html__('', 'xen'),
							'required' => array('en_footer_logo_opt', '=' , 'st2')
					),
					
					$fields = array(
					'id'       => 'opt_footer_logo_dimensions',
					'type'     => 'dimensions',
					'units'    => array('em','px','%'),
					'output' => array('.footer-logo'),
					'title'    => __('Logo Size', 'xen'),
					'subtitle' => __('.', 'xen'),
					'desc'     => __('Optional', 'xen'),
					'default'  => array(
						'Width'   => '113', 
						'Height'  => '65'
					),
					'required' => array('en_footer_logo_opt', '=' , 'st2')
				),
				
				
					
					
					
					array(
							'id' => 'theme-cus-copy',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_html__('Website Copyright Text', 'xen'),
							'desc' => esc_html__('Write a Copyright text of your WebSite.', 'xen')
							
					  ),
					
					array(
							'id' => 'copyright',
							'type' => 'editor',
							'wpautop'=>true,
							'compiler' => 'true',
							'title' => esc_html__('Copyright text of the WebSite', 'xen'),
							'subtitle' => esc_html__('Insert your custom Copyright text.', 'xen'),
							'default'          => '&copy; Copyright 2020 XEN. Theme by webRedox',
							'args'   => array(
								'teeny'            => true,
								'textarea_rows'    => 10
							)
					),
					
					
					)
                ) );
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-key',
                    'title'  => esc_html__( 'Documentation', 'xen' ),
                    'fields' => array(					
					
					array(
							'id' => 'docs',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_html__('XEN Theme Documentation', 'xen'),
							'desc' => __('<a href="http://webredox.net/demo/wp/xen/doc/documentation.html" target="_blank">Click Here</a> To get the theme documentation.', 'xen')
							
					),	

					)
                ));
				
				
    /*
     * <--- END SECTIONS
     */


    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */

    /*
    *
    * --> Action hook examples
    *
    */

    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    //add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action( $options, $css, $changed_values ) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r( $changed_values ); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
        }
    }

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $return['error'] = $field;
                $field['msg']    = 'your custom error message';
            }

            if ( $warning == true ) {
                $return['warning'] = $field;
                $field['msg']      = 'your custom warning message';
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => esc_html__( 'Section via hook', 'xen' ),
                'desc'   => esc_html__( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'xen' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }

    /**
     * Removes the demo link and the notice of integrated demo from the redux-xen plugin
     */
    if ( ! function_exists( 'remove_demo' ) ) {
        function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                remove_filter( 'plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), null, 2 );

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
            }
        }
    }

